@@ -1,13 +1,14 @@
 import logging
 import time
+import warnings
 
 from django.conf import settings
 
-import wrapt
+from decorator import decorator
 
 
-@wrapt.decorator()
-def db_model(wrapped, instance, args, kwargs):
+@decorator
+def db_model(func, *args, **kwargs):
     """
     Converts a JSON representation of a Django model into an actual model.
 
@@ -15,22 +16,29 @@ def db_model(wrapped, instance, args, kwargs):
         @db_model
         def delete(self, model):
             ...
-    
+
     Will get converted to:
         `component.delete({ 'name': 'modelName', pk: 1})` -> `component.delete(modelInstance)`
     """
 
+    warnings.warn(
+        "db_model is deprecated and will be removed in 0.28.0", stacklevel=2,
+    )
+
+    instance = args[0]
+    model_dictionary = args[1]
+
     if hasattr(instance, "Meta") and hasattr(instance.Meta, "db_models"):
-        db_model_name = args[0].get("name")
+        db_model_name = model_dictionary.get("name")
         assert db_model_name, "Missing db model name"
-        db_model_pk = args[0].get("pk")
+        db_model_pk = model_dictionary.get("pk")
         assert db_model_pk, "Missing db model pk"
         db_model_found = False
 
         for db_model in instance.Meta.db_models:
             if db_model.name == db_model_name:
                 model = db_model.model_class.objects.get(pk=db_model_pk)
-                args = (model,) + args[1:]
+                args = (instance, model,) + args[2:]
                 db_model_found = True
                 break
 
@@ -38,32 +46,27 @@ def db_model(wrapped, instance, args, kwargs):
     else:
         raise AssertionError("No db_models defined")
 
-    result = wrapped(*args, **kwargs)
+    result = func(*args, **kwargs)
 
     return result
 
 
-def _timed_enabled():
-    return settings.DEBUG
-
-
-@wrapt.decorator(enabled=_timed_enabled)
-def timed(wrapped, instance, args, kwargs):
+@decorator
+def timed(func, *args, **kwargs):
     """
     Decorator that prints out the timing of a function.
 
     Slightly altered version of https://gist.github.com/bradmontgomery/bd6288f09a24c06746bbe54afe4b8a82.
     """
+    if not settings.DEBUG:
+        return func(*args, **kwargs)
+
     logger = logging.getLogger("profile")
     start = time.time()
-    result = wrapped(*args, **kwargs)
+    result = func(*args, **kwargs)
     end = time.time()
 
-    function_name = wrapped.__name__
-
-    if instance:
-        function_name = f"{instance}.{function_name}"
-
+    function_name = func.__name__
     arguments = ""
 
     if args:
